@@ -1,8 +1,7 @@
-import warnings
-
 import xarray as xr
 
 from ..echodata import EchoData
+from ..utils.log import _init_logger
 from ..utils.prov import echopype_prov_attrs, source_files_vars
 from .calibrate_azfp import CalibrateAZFP
 from .calibrate_ek import CalibrateEK60, CalibrateEK80
@@ -16,6 +15,8 @@ CALIBRATOR = {
     "EA640": CalibrateEK80,
 }
 
+logger = _init_logger(__name__)
+
 
 def _compute_cal(
     cal_type,
@@ -39,12 +40,12 @@ def _compute_cal(
             )
     elif echodata.sonar_model in ("EK60", "AZFP"):
         if waveform_mode is not None and waveform_mode != "CW":
-            warnings.warn(
+            logger.warning(
                 "This sonar model transmits only narrowband signals (waveform_mode='CW'). "
                 "Calibration will be in CW mode",
             )
         if encode_mode is not None and encode_mode != "power":
-            warnings.warn(
+            logger.warning(
                 "This sonar model only record data as power or power/angle samples "
                 "(encode_mode='power'). Calibration will be done on the power samples.",
             )
@@ -104,9 +105,9 @@ def _compute_cal(
     prov_dict["processing_function"] = f"calibrate.compute_{cal_type}"
     cal_ds = cal_ds.assign_attrs(prov_dict)
 
-    if "water_level" in echodata.platform.data_vars.keys():
+    if "water_level" in echodata["Platform"].data_vars.keys():
         # add water_level to the created xr.Dataset
-        cal_ds["water_level"] = echodata.platform.water_level
+        cal_ds["water_level"] = echodata["Platform"].water_level
 
     return cal_ds
 
