@@ -4,8 +4,11 @@ from scipy import signal
 
 from ..echodata import EchoData
 from ..utils import uwa
+from ..utils.log import _init_logger
 from .calibrate_base import CAL_PARAMS, CalibrateBase
 
+logger = _init_logger(__name__)
+
 
 class CalibrateEK(CalibrateBase):
     def __init__(self, echodata: EchoData, env_params):
@@ -54,7 +57,7 @@ class CalibrateEK(CalibrateBase):
         param : str {"sa_correction", "gain_correction"}
             name of parameter to retrieve
         """
-        ds_vend = self.echodata.vendor
+        ds_vend = self.echodata["Vendor_specific"]
 
         if ds_vend is None or param not in ds_vend:
             return None
@@ -62,10 +65,10 @@ class CalibrateEK(CalibrateBase):
         if param not in ["sa_correction", "gain_correction"]:
             raise ValueError(f"Unknown parameter {param}")
 
-        if waveform_mode == "CW" and self.echodata.beam_power is not None:
-            beam = self.echodata.beam_power
+        if waveform_mode == "CW" and self.echodata["Sonar/Beam_group2"] is not None:
+            beam = self.echodata["Sonar/Beam_group2"]
         else:
-            beam = self.echodata.beam
+            beam = self.echodata["Sonar/Beam_group1"]
 
         # indexes of frequencies that are for power, not complex
         relevant_indexes = np.where(
@@ -105,11 +108,11 @@ class CalibrateEK(CalibrateBase):
         if (
             encode_mode == "power"
             and waveform_mode == "CW"
-            and self.echodata.beam_power is not None
+            and self.echodata["Sonar/Beam_group2"] is not None
         ):
-            beam = self.echodata.beam_power
+            beam = self.echodata["Sonar/Beam_group2"]
         else:
-            beam = self.echodata.beam
+            beam = self.echodata["Sonar/Beam_group1"]
 
         # Params from the Vendor_specific group
 
@@ -141,8 +144,9 @@ class CalibrateEK(CalibrateBase):
             'TS' for calculating target strength
         use_beam_power : bool
             whether to use beam_power.
-            If ``True`` use ``echodata.beam_power``; if ``False`` use ``echodata.beam``.
-            Note ``echodata.beam_power`` could only exist for EK80 data.
+            If ``True`` use ``echodata["Sonar/Beam_group2"]``;
+            if ``False`` use ``echodata["Sonar/Beam_group1"]``.
+            Note ``echodata["Sonar/Beam_group2"]`` could only exist for EK80 data.
 
         Returns
         -------
@@ -151,9 +155,9 @@ class CalibrateEK(CalibrateBase):
         """
         # Select source of backscatter data
         if use_beam_power:
-            beam = self.echodata.beam_power
+            beam = self.echodata["Sonar/Beam_group2"]
         else:
-            beam = self.echodata.beam
+            beam = self.echodata["Sonar/Beam_group1"]
 
         # Harmonize time coordinate between Beam_groupX data and env_params
         for p in self.env_params.keys():
@@ -261,7 +265,7 @@ class CalibrateEK60(CalibrateEK):
                 pressure=self.env_params["pressure"],
             )
             self.env_params["sound_absorption"] = uwa.calc_absorption(
-                frequency=self.echodata.beam["frequency_nominal"],
+                frequency=self.echodata["Sonar/Beam_group1"]["frequency_nominal"],
                 temperature=self.env_params["temperature"],
                 salinity=self.env_params["salinity"],
                 pressure=self.env_params["pressure"],
@@ -271,12 +275,12 @@ class CalibrateEK60(CalibrateEK):
             self.env_params["sound_speed"] = (
                 self.env_params["sound_speed"]
                 if "sound_speed" in self.env_params
-                else self.echodata.environment["sound_speed_indicative"]
+                else self.echodata["Environment"]["sound_speed_indicative"]
             )
             self.env_params["sound_absorption"] = (
                 self.env_params["sound_absorption"]
                 if "sound_absorption" in self.env_params
-                else self.echodata.environment["absorption_indicative"]
+                else self.echodata["Environment"]["absorption_indicative"]
             )
 
     def compute_Sv(self, **kwargs):
@@ -340,11 +344,11 @@ class CalibrateEK80(CalibrateEK):
         if (
             encode_mode == "power"
             and waveform_mode == "CW"
-            and self.echodata.beam_power is not None
+            and self.echodata["Sonar/Beam_group2"] is not None
         ):
-            beam = self.echodata.beam_power
+            beam = self.echodata["Sonar/Beam_group2"]
         else:
-            beam = self.echodata.beam
+            beam = self.echodata["Sonar/Beam_group1"]
 
         # Use center frequency if in BB mode, else use nominal channel frequency
         if waveform_mode == "BB":
@@ -380,12 +384,14 @@ class CalibrateEK80(CalibrateEK):
                 ["temperature", "salinity", "depth"],
             ):
                 self.env_params[p1] = (
-                    self.env_params[p1] if p1 in self.env_params else self.echodata.environment[p2]
+                    self.env_params[p1]
+                    if p1 in self.env_params
+                    else self.echodata["Environment"][p2]
                 )
             self.env_params["sound_speed"] = (
                 self.env_params["sound_speed"]
                 if "sound_speed" in self.env_params
-                else self.echodata.environment["sound_speed_indicative"]
+                else self.echodata["Environment"]["sound_speed_indicative"]
             )
             self.env_params["sound_absorption"] = (
                 self.env_params["sound_absorption"]
@@ -411,16 +417,18 @@ class CalibrateEK80(CalibrateEK):
             'coeff' or 'decimation'
         """
         if param_type == "coeff":
-            v = self.echodata.vendor.attrs[
+            v = self.echodata["Vendor_specific"].attrs[
                 "%s %s filter_r" % (channel_id, filter_name)
             ] + 1j * np.array(
-                self.echodata.vendor.attrs["%s %s filter_i" % (channel_id, filter_name)]
+                self.echodata["Vendor_specific"].attrs["%s %s filter_i" % (channel_id, filter_name)]
             )
             if v.size == 1:
                 v = np.expand_dims(v, axis=0)  # expand dims for convolution
             return v
         else:
-            return self.echodata.vendor.attrs["%s %s decimation" % (channel_id, filter_name)]
+            return self.echodata["Vendor_specific"].attrs[
+                "%s %s decimation" % (channel_id, filter_name)
+            ]
 
     def _tapered_chirp(
         self,
@@ -513,15 +521,15 @@ class CalibrateEK80(CalibrateEK):
         """
         # Make sure it is BB mode data
         if waveform_mode == "BB" and (
-            ("frequency_start" not in self.echodata.beam)
-            or ("frequency_end" not in self.echodata.beam)
+            ("frequency_start" not in self.echodata["Sonar/Beam_group1"])
+            or ("frequency_end" not in self.echodata["Sonar/Beam_group1"])
         ):
             raise TypeError("File does not contain BB mode complex samples!")
 
         y_all = {}
         y_time_all = {}
         tau_effective = {}
-        for chan in self.echodata.beam.channel.values:
+        for chan in self.echodata["Sonar/Beam_group1"].channel.values:
             # TODO: currently only deal with the case with
             # a fixed tx key param values within a channel
             if waveform_mode == "BB":
@@ -541,13 +549,15 @@ class CalibrateEK80(CalibrateEK):
                 ]
             tx_params = {}
             for p in tx_param_names:
-                tx_params[p] = np.unique(self.echodata.beam[p].sel(channel=chan))
+                tx_params[p] = np.unique(self.echodata["Sonar/Beam_group1"][p].sel(channel=chan))
                 if tx_params[p].size != 1:
                     raise TypeError("File contains changing %s!" % p)
             y_tmp, _ = self._tapered_chirp(**tx_params)
 
             # Filter and decimate chirp template
-            fs_deci = 1 / self.echodata.beam.sel(channel=chan)["sample_interval"].values
+            fs_deci = (
+                1 / self.echodata["Sonar/Beam_group1"].sel(channel=chan)["sample_interval"].values
+            )
             y_tmp, y_tmp_time = self._filter_decimate_chirp(y_tmp, chan)
 
             # Compute effective pulse length
@@ -570,9 +580,9 @@ class CalibrateEK80(CalibrateEK):
             channels that transmit in BB mode
             (since CW mode can be in mixed in complex samples too)
         """
-        backscatter = self.echodata.beam["backscatter_r"].sel(
+        backscatter = self.echodata["Sonar/Beam_group1"]["backscatter_r"].sel(
             channel=chan_BB
-        ) + 1j * self.echodata.beam["backscatter_i"].sel(channel=chan_BB)
+        ) + 1j * self.echodata["Sonar/Beam_group1"]["backscatter_i"].sel(channel=chan_BB)
 
         pc_all = []
         for chan in chan_BB:
@@ -622,26 +632,28 @@ class CalibrateEK80(CalibrateEK):
                 "gain_correction", waveform_mode=waveform_mode
             )
             gain = []
-            if "gain" in self.echodata.vendor.data_vars:
+            if "gain" in self.echodata["Vendor_specific"].data_vars:
                 # index using channel_id as order of frequency across channel can be arbitrary
                 # reference to freq_center in case some channels are CW complex samples
                 # (already dropped when computing freq_center in the calling function)
                 for ch_id in chan_sel:
                     # if channel gain exists in data
-                    if ch_id in self.echodata.vendor.cal_channel_id:
-                        gain_vec = self.echodata.vendor.gain.sel(cal_channel_id=ch_id)
+                    if ch_id in self.echodata["Vendor_specific"].cal_channel_id:
+                        gain_vec = self.echodata["Vendor_specific"].gain.sel(cal_channel_id=ch_id)
                         gain_temp = (
                             gain_vec.interp(
-                                cal_frequency=self.echodata.vendor.frequency_nominal.sel(
-                                    channel=ch_id
-                                )
+                                cal_frequency=self.echodata[
+                                    "Vendor_specific"
+                                ].frequency_nominal.sel(channel=ch_id)
                             ).drop(["cal_channel_id", "cal_frequency"])
                         ).expand_dims("channel")
                     # if no freq-dependent gain use CW gain
                     else:
                         gain_temp = (
                             gain_single.sel(channel=ch_id)
-                            .reindex_like(self.echodata.beam.backscatter_r, method="nearest")
+                            .reindex_like(
+                                self.echodata["Sonar/Beam_group1"].backscatter_r, method="nearest"
+                            )
                             .expand_dims("channel")
                         )
                     gain_temp.name = "gain"
@@ -682,9 +694,13 @@ class CalibrateEK80(CalibrateEK):
 
         # use center frequency for each ping to select BB or CW channels
         # when all samples are encoded as complex samples
-        if "frequency_start" in self.echodata.beam and "frequency_end" in self.echodata.beam:
+        if (
+            "frequency_start" in self.echodata["Sonar/Beam_group1"]
+            and "frequency_end" in self.echodata["Sonar/Beam_group1"]
+        ):
             freq_center = (
-                self.echodata.beam["frequency_start"] + self.echodata.beam["frequency_end"]
+                self.echodata["Sonar/Beam_group1"]["frequency_start"]
+                + self.echodata["Sonar/Beam_group1"]["frequency_end"]
             ) / 2  # has beam dim
         else:
             freq_center = None
@@ -702,7 +718,7 @@ class CalibrateEK80(CalibrateEK):
             # backscatter data
             pc = self.compress_pulse(chirp, chan_BB=chan_sel)  # has beam dim
             prx = (
-                self.echodata.beam.beam.size
+                self.echodata["Sonar/Beam_group1"].beam.size
                 * np.abs(pc.mean(dim="beam")) ** 2
                 / (2 * np.sqrt(2)) ** 2
                 * (np.abs(self.z_er + self.z_et) / self.z_er) ** 2
@@ -711,7 +727,7 @@ class CalibrateEK80(CalibrateEK):
         else:
             if freq_center is None:
                 # when only have CW complex samples
-                chan_sel = self.echodata.beam.channel
+                chan_sel = self.echodata["Sonar/Beam_group1"].channel
             else:
                 # if BB and CW complex samples co-exist
                 # drop those that contain BB samples (not nan in freq start/end)
@@ -719,10 +735,11 @@ class CalibrateEK80(CalibrateEK):
 
             # backscatter data
             backscatter_cw = (
-                self.echodata.beam["backscatter_r"] + 1j * self.echodata.beam["backscatter_i"]
+                self.echodata["Sonar/Beam_group1"]["backscatter_r"]
+                + 1j * self.echodata["Sonar/Beam_group1"]["backscatter_i"]
             )
             prx = (
-                self.echodata.beam.beam.size
+                self.echodata["Sonar/Beam_group1"].beam.size
                 * np.abs(backscatter_cw.mean(dim="beam")) ** 2
                 / (2 * np.sqrt(2)) ** 2
                 * (np.abs(self.z_er + self.z_et) / self.z_er) ** 2
@@ -734,10 +751,10 @@ class CalibrateEK80(CalibrateEK):
         # Compute derived params
 
         # Harmonize time coordinate between Beam_groupX data and env_params
-        # Use self.echodata.beam because complex sample is always in Beam_group1
+        # Use self.echodata["Sonar/Beam_group1"] because complex sample is always in Beam_group1
         for p in self.env_params.keys():
             self.env_params[p] = self.echodata._harmonize_env_param_time(
-                self.env_params[p], ping_time=self.echodata.beam.ping_time
+                self.env_params[p], ping_time=self.echodata["Sonar/Beam_group1"].ping_time
             )
 
         sound_speed = self.env_params["sound_speed"]
@@ -745,14 +762,18 @@ class CalibrateEK80(CalibrateEK):
         range_meter = self.range_meter.sel(channel=chan_sel)
         if waveform_mode == "BB":
             # use true center frequency for BB pulse
-            wavelength = sound_speed / self.echodata.beam.frequency_nominal.sel(channel=chan_sel)
+            wavelength = sound_speed / self.echodata["Sonar/Beam_group1"].frequency_nominal.sel(
+                channel=chan_sel
+            )
 
             # use true center frequency to interpolate for gain factor
             gain = self._get_gain_for_complex(waveform_mode=waveform_mode, chan_sel=chan_sel)
 
         else:
             # use nominal channel frequency for CW pulse
-            wavelength = sound_speed / self.echodata.beam.frequency_nominal.sel(channel=chan_sel)
+            wavelength = sound_speed / self.echodata["Sonar/Beam_group1"].frequency_nominal.sel(
+                channel=chan_sel
+            )
 
             # use nominal channel frequency to select gain factor
             gain = self._get_gain_for_complex(waveform_mode=waveform_mode, chan_sel=chan_sel)
@@ -767,21 +788,29 @@ class CalibrateEK80(CalibrateEK):
             # effective pulse length
             tau_effective = xr.DataArray(
                 data=list(tau_effective.values()),
-                coords=[self.echodata.beam.channel, self.echodata.beam.ping_time],
+                coords=[
+                    self.echodata["Sonar/Beam_group1"].channel,
+                    self.echodata["Sonar/Beam_group1"].ping_time,
+                ],
                 dims=["channel", "ping_time"],
             ).sel(channel=chan_sel)
 
             # other params
-            transmit_power = self.echodata.beam["transmit_power"].sel(channel=chan_sel)
+            transmit_power = self.echodata["Sonar/Beam_group1"]["transmit_power"].sel(
+                channel=chan_sel
+            )
             # equivalent_beam_angle has beam dim
             if waveform_mode == "BB":
-                psifc = self.echodata.beam["equivalent_beam_angle"].sel(
+                psifc = self.echodata["Sonar/Beam_group1"]["equivalent_beam_angle"].sel(
                     channel=chan_sel
                 ) + 10 * np.log10(
-                    self.echodata.vendor.frequency_nominal.sel(channel=chan_sel) / freq_center
+                    self.echodata["Vendor_specific"].frequency_nominal.sel(channel=chan_sel)
+                    / freq_center
                 )
             elif waveform_mode == "CW":
-                psifc = self.echodata.beam["equivalent_beam_angle"].sel(channel=chan_sel)
+                psifc = self.echodata["Sonar/Beam_group1"]["equivalent_beam_angle"].sel(
+                    channel=chan_sel
+                )
 
             out = (
                 10 * np.log10(prx)
@@ -795,7 +824,9 @@ class CalibrateEK80(CalibrateEK):
             out = out.rename_vars({list(out.data_vars.keys())[0]: "Sv"})
 
         elif cal_type == "TS":
-            transmit_power = self.echodata.beam["transmit_power"].sel(channel=chan_sel)
+            transmit_power = self.echodata["Sonar/Beam_group1"]["transmit_power"].sel(
+                channel=chan_sel
+            )
 
             out = (
                 10 * np.log10(prx)
@@ -810,7 +841,7 @@ class CalibrateEK80(CalibrateEK):
         out = out.merge(range_meter)
 
         # Add frequency_nominal to data set
-        out["frequency_nominal"] = self.echodata.beam["frequency_nominal"]
+        out["frequency_nominal"] = self.echodata["Sonar/Beam_group1"]["frequency_nominal"]
 
         # Add env and cal parameters
         out = self._add_params_to_output(out)
@@ -879,22 +910,22 @@ class CalibrateEK80(CalibrateEK):
         # Raise error when waveform_mode and actual recording mode do not match
         # This simple check is only possible for BB-only data,
         #   since for data with both BB and CW complex samples,
-        #   frequency_start will exist in echodata.beam for the BB channels
-        if waveform_mode == "BB" and "frequency_start" not in self.echodata.beam:
+        #   frequency_start will exist in echodata["Sonar/Beam_group1"] for the BB channels
+        if waveform_mode == "BB" and "frequency_start" not in self.echodata["Sonar/Beam_group1"]:
             raise ValueError("waveform_mode='BB' but broadband data not found!")
 
         # Set use_beam_power
-        #  - True: use self.echodata.beam_power for cal
-        #  - False: use self.echodata.beam for cal
+        #  - True: use self.echodata["Sonar/Beam_group2"] for cal
+        #  - False: use self.echodata["Sonar/Beam_group1"] for cal
         use_beam_power = False
 
         # Warn user about additional data in the raw file if another type exists
         # When both power and complex samples exist:
-        #   complex samples will be stored in echodata.beam
-        #   power samples will be stored in echodata.beam_power
+        #   complex samples will be stored in echodata["Sonar/Beam_group1"]
+        #   power samples will be stored in echodata["Sonar/Beam_group2"]
         # When only one type of samples exist,
-        #   all samples with be stored in echodata.beam
-        if self.echodata.beam_power is not None:  # both power and complex samples exist
+        #   all samples with be stored in echodata["Sonar/Beam_group1"]
+        if self.echodata["Sonar/Beam_group2"] is not None:  # both power and complex samples exist
             # If both beam and beam_power groups exist,
             #   this means that CW data are encoded as power samples and in beam_power group
             if waveform_mode == "CW" and encode_mode == "complex":
@@ -902,15 +933,17 @@ class CalibrateEK80(CalibrateEK):
 
             if encode_mode == "power":
                 use_beam_power = True  # switch source of backscatter data
-                print(
+                logger.info(
                     "Only power samples are calibrated, but complex samples also exist in the raw data file!"  # noqa
                 )
             else:
-                print(
+                logger.info(
                     "Only complex samples are calibrated, but power samples also exist in the raw data file!"  # noqa
                 )
         else:  # only power OR complex samples exist
-            if "backscatter_i" in self.echodata.beam.variables:  # data contain only complex samples
+            if (
+                "backscatter_i" in self.echodata["Sonar/Beam_group1"].variables
+            ):  # data contain only complex samples
                 if encode_mode == "power":
                     raise TypeError(
                         "File does not contain power samples! Use encode_mode='complex'"
