@@ -9,6 +9,8 @@ from .convert.parse_ad2cp import ParseAd2cp
 from .convert.parse_azfp import ParseAZFP
 from .convert.parse_ek60 import ParseEK60
 from .convert.parse_ek80 import ParseEK80
+from .convert.parsed_to_zarr_ek60 import Parsed2ZarrEK60
+from .convert.parsed_to_zarr_ek80 import Parsed2ZarrEK80
 from .convert.set_groups_ad2cp import SetGroupsAd2cp
 from .convert.set_groups_azfp import SetGroupsAZFP
 from .convert.set_groups_ek60 import SetGroupsEK60
@@ -43,6 +45,7 @@ SONAR_MODELS: Dict["SonarModelsHint", Dict[str, Any]] = {
         "validate_ext": validate_azfp_ext,
         "xml": True,
         "parser": ParseAZFP,
+        "parsed2zarr": None,
         "set_groups": SetGroupsAZFP,
         "concat_dims": {
             "platform": "time2",
@@ -54,11 +57,13 @@ SONAR_MODELS: Dict["SonarModelsHint", Dict[str, Any]] = {
             "platform": "all",
             "default": "minimal",
         },
+        "dgram_zarr_vars": {},
     },
     "EK60": {
         "validate_ext": validate_ext(".raw"),
         "xml": False,
         "parser": ParseEK60,
+        "parsed2zarr": Parsed2ZarrEK60,
         "set_groups": SetGroupsEK60,
         "concat_dims": {
             "platform": ["time1", "time2", "time3"],
@@ -69,11 +74,13 @@ SONAR_MODELS: Dict["SonarModelsHint", Dict[str, Any]] = {
         "concat_data_vars": {
             "default": "minimal",
         },
+        "dgram_zarr_vars": {"power": ["timestamp", "channel"], "angle": ["timestamp", "channel"]},
     },
     "ES70": {
         "validate_ext": validate_ext(".raw"),
         "xml": False,
         "parser": ParseEK60,
+        "parsed2zarr": Parsed2ZarrEK60,
         "set_groups": SetGroupsEK60,
         "concat_dims": {
             "platform": ["time1", "time2", "time3"],
@@ -84,11 +91,13 @@ SONAR_MODELS: Dict["SonarModelsHint", Dict[str, Any]] = {
         "concat_data_vars": {
             "default": "minimal",
         },
+        "dgram_zarr_vars": {"power": ["timestamp", "channel"], "angle": ["timestamp", "channel"]},
     },
     "EK80": {
         "validate_ext": validate_ext(".raw"),
         "xml": False,
         "parser": ParseEK80,
+        "parsed2zarr": Parsed2ZarrEK80,
         "set_groups": SetGroupsEK80,
         "concat_dims": {
             "platform": ["time1", "time2", "time3"],
@@ -99,11 +108,17 @@ SONAR_MODELS: Dict["SonarModelsHint", Dict[str, Any]] = {
         "concat_data_vars": {
             "default": "minimal",
         },
+        "dgram_zarr_vars": {
+            "power": ["timestamp", "channel_id"],
+            "complex": ["timestamp", "channel_id"],
+            "angle": ["timestamp", "channel_id"],
+        },
     },
     "ES80": {
         "validate_ext": validate_ext(".raw"),
         "xml": False,
         "parser": ParseEK80,
+        "parsed2zarr": Parsed2ZarrEK80,
         "set_groups": SetGroupsEK80,
         "concat_dims": {
             "platform": ["time1", "time2", "time3"],
@@ -114,11 +129,17 @@ SONAR_MODELS: Dict["SonarModelsHint", Dict[str, Any]] = {
         "concat_data_vars": {
             "default": "minimal",
         },
+        "dgram_zarr_vars": {
+            "power": ["timestamp", "channel_id"],
+            "complex": ["timestamp", "channel_id"],
+            "angle": ["timestamp", "channel_id"],
+        },
     },
     "EA640": {
         "validate_ext": validate_ext(".raw"),
         "xml": False,
         "parser": ParseEK80,
+        "parsed2zarr": Parsed2ZarrEK80,
         "set_groups": SetGroupsEK80,
         "concat_dims": {
             "platform": ["time1", "time2", "time3"],
@@ -129,11 +150,17 @@ SONAR_MODELS: Dict["SonarModelsHint", Dict[str, Any]] = {
         "concat_data_vars": {
             "default": "minimal",
         },
+        "dgram_zarr_vars": {
+            "power": ["timestamp", "channel_id"],
+            "complex": ["timestamp", "channel_id"],
+            "angle": ["timestamp", "channel_id"],
+        },
     },
     "AD2CP": {
         "validate_ext": validate_ext(".ad2cp"),
         "xml": False,
         "parser": ParseAd2cp,
+        "parsed2zarr": None,
         "set_groups": SetGroupsAd2cp,
         "concat_dims": {
             "platform": "ping_time",
@@ -144,5 +171,6 @@ SONAR_MODELS: Dict["SonarModelsHint", Dict[str, Any]] = {
         "concat_data_vars": {
             "default": "minimal",
         },
+        "dgram_zarr_vars": {},
     },
 }
