@@ -17,9 +17,7 @@ def _clean_ping_time(ping_time_old, local_win_len=100):
             (
                 ping_time_old[: ni + 1],
                 ping_time_old[ni]
-                + np.cumsum(
-                    np.hstack((local_pt_median, ping_time_old_diff[(ni + 1) :]))
-                ),
+                + np.cumsum(np.hstack((local_pt_median, ping_time_old_diff[(ni + 1) :]))),
             )
         )
         return _clean_ping_time(ping_time_new, local_win_len=local_win_len)
@@ -31,7 +29,7 @@ def coerce_increasing_time(ds, time_name="ping_time", local_win_len=100):
     """Coerce a time coordinate to always flow forward.
 
     This is to correct for problems sometimes observed in EK60 data
-    where a time coordinate (``ping_time`` or ``location_time``)
+    where a time coordinate (``ping_time`` or ``time1``)
     would suddenly go backward for one ping but with the rest of the pinging interval undisturbed.
 
     Parameters
