@@ -20,11 +20,7 @@ DEFAULT_TIME_ENCODING = {
 
 DEFAULT_ENCODINGS = {
     "ping_time": DEFAULT_TIME_ENCODING,
-    "ping_time_burst": DEFAULT_TIME_ENCODING,
-    "ping_time_average": DEFAULT_TIME_ENCODING,
-    "ping_time_echosounder": DEFAULT_TIME_ENCODING,
-    "ping_time_echosounder_raw": DEFAULT_TIME_ENCODING,
-    "ping_time_echosounder_raw_transmit": DEFAULT_TIME_ENCODING,
+    "ping_time_transmit": DEFAULT_TIME_ENCODING,
     "time1": DEFAULT_TIME_ENCODING,
     "time2": DEFAULT_TIME_ENCODING,
     "time3": DEFAULT_TIME_ENCODING,
